@@ -7,6 +7,7 @@ from dataclasses import dataclass
 from typing import Any
 from typing import Optional
 from typing import cast
+from warnings import warn
 
 from marshmallow.schema import Schema
 
@@ -70,33 +71,100 @@ GATEWAY_SPECIFICATIONS: dict[str, dict[str, Any]] = {
     },
 }
 
-_DEFAULT_ENDPOINTS: dict[str, str] = {
-    "alerts": "/vehicles/{vin}/alerts",
-    "battery-status": "/kca/car-adapter/v2/cars/{vin}/battery-status",
-    "charge-history": "/kca/car-adapter/v1/cars/{vin}/charge-history",
-    "charge-mode": "/kca/car-adapter/v1/cars/{vin}/charge-mode",
-    "charge-schedule": "/kca/car-adapter/v1/cars/{vin}/charge-schedule",
-    "charges": "/kca/car-adapter/v1/cars/{vin}/charges",
-    "charging-settings": "/kca/car-adapter/v1/cars/{vin}/charging-settings",
-    "cockpit": "/kca/car-adapter/v1/cars/{vin}/cockpit",
-    "hvac-history": "/kca/car-adapter/v1/cars/{vin}/hvac-history",
-    "hvac-sessions": "/kca/car-adapter/v1/cars/{vin}/hvac-sessions",
-    "hvac-settings": "/kca/car-adapter/v1/cars/{vin}/hvac-settings",
-    "hvac-status": "/kca/car-adapter/v1/cars/{vin}/hvac-status",
-    "location": "/kca/car-adapter/v1/cars/{vin}/location",
-    "lock-status": "/kca/car-adapter/v1/cars/{vin}/lock-status",
-    "notification-settings": "/kca/car-adapter/v1/cars/{vin}/notification-settings",
-    "pressure": "/kca/car-adapter/v1/cars/{vin}/pressure",
-    "res-state": "/kca/car-adapter/v1/cars/{vin}/res-state",
-    "soc-levels": "/kcm/v1/vehicles/{vin}/ev/soc-levels",
+
+@dataclass
+class EndpointDefinition:
+    endpoint: str
+    mode: str = "default"
+
+
+_DEFAULT_ENDPOINTS: dict[str, EndpointDefinition] = {
+    "actions/charge-set-mode": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/charge-mode"
+    ),
+    "actions/charge-set-schedule": EndpointDefinition(
+        "/kca/car-adapter/v2/cars/{vin}/actions/charge-schedule"
+    ),
+    "actions/charge-start": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/charging-start"
+    ),
+    "actions/charge-stop": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/charging-start"
+    ),
+    "actions/horn-start": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/horn-lights"
+    ),
+    "actions/hvac-set-schedule": EndpointDefinition(
+        "/kca/car-adapter/v2/cars/{vin}/actions/hvac-schedule"
+    ),
+    "actions/hvac-start": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/hvac-start"
+    ),
+    "actions/hvac-stop": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/hvac-start"
+    ),
+    "actions/lights-start": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/actions/horn-lights"
+    ),
+    "alerts": EndpointDefinition("/vehicles/{vin}/alerts"),
+    "battery-status": EndpointDefinition(
+        "/kca/car-adapter/v2/cars/{vin}/battery-status"
+    ),
+    "charge-history": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/charge-history"
+    ),
+    "charge-mode": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/charge-mode"),
+    "charge-schedule": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/charge-schedule"
+    ),
+    "charges": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/charges"),
+    "charging-settings": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/charging-settings"
+    ),
+    "cockpit": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/cockpit"),
+    "hvac-history": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/hvac-history"),
+    "hvac-sessions": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/hvac-sessions"),
+    "hvac-settings": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/hvac-settings"),
+    "hvac-status": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/hvac-status"),
+    "location": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/location"),
+    "lock-status": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/lock-status"),
+    "notification-settings": EndpointDefinition(
+        "/kca/car-adapter/v1/cars/{vin}/notification-settings"
+    ),
+    "pressure": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/pressure"),
+    "res-state": EndpointDefinition("/kca/car-adapter/v1/cars/{vin}/res-state"),
+    "soc-levels": EndpointDefinition("/kcm/v1/vehicles/{vin}/ev/soc-levels"),
 }
-_KCM_ENDPOINTS: dict[str, str] = {
-    "charge-schedule": "/kcm/v1/vehicles/{vin}/ev/settings"
+_KCM_ENDPOINTS: dict[str, EndpointDefinition] = {
+    "actions/charge-start": EndpointDefinition(
+        "/kcm/v1/vehicles/{vin}/charge/pause-resume", mode="kcm"
+    ),
+    "actions/charge-stop": EndpointDefinition(
+        "/kcm/v1/vehicles/{vin}/charge/pause-resume", mode="kcm"
+    ),
+    "charge-schedule": EndpointDefinition(
+        "/kcm/v1/vehicles/{vin}/ev/settings", mode="kcm"
+    ),
 }
 
-_VEHICLE_ENDPOINTS: dict[str, dict[str, Optional[str]]] = {
+_VEHICLE_ENDPOINTS: dict[str, dict[str, Optional[EndpointDefinition]]] = {
     "R5E1VE": {  # Renault 5 E-TECH
+        "actions/horn-start": _DEFAULT_ENDPOINTS["actions/horn-start"],
+        "actions/hvac-start": _DEFAULT_ENDPOINTS["actions/hvac-start"],
+        "actions/lights-start": _DEFAULT_ENDPOINTS["actions/lights-start"],
+        "battery-status": _DEFAULT_ENDPOINTS["battery-status"],
+        "charge-history": None,  # Reason: "you should not be there..."
+        "charge-mode": None,  # Reason: The access is forbidden
         "charge-schedule": _KCM_ENDPOINTS["charge-schedule"],
+        "charges": _DEFAULT_ENDPOINTS["charges"],
+        "cockpit": _DEFAULT_ENDPOINTS["cockpit"],
+        "hvac-settings": _DEFAULT_ENDPOINTS["hvac-settings"],
+        "hvac-status": _DEFAULT_ENDPOINTS["hvac-status"],
+        "location": _DEFAULT_ENDPOINTS["location"],
+        "lock-status": None,  # Reason: 404
+        "pressure": None,  # Reason: 404
+        "res-state": None,  # Reason: The access is forbidden
+        "soc-levels": _DEFAULT_ENDPOINTS["soc-levels"],
     },
     "X071VE": {  # TWINGO III
         "res-state": None,  # not supported
@@ -122,6 +190,8 @@ _VEHICLE_ENDPOINTS: dict[str, dict[str, Optional[str]]] = {
         "lock-status": None,
         "res-state": None,
         "charge-mode": None,
+        "actions/charge-start": _KCM_ENDPOINTS["actions/charge-start"],
+        "actions/charge-stop": _KCM_ENDPOINTS["actions/charge-stop"],
     },
     "XCB1SE": {  # SCENIC E-TECH
         "charge-schedule": _KCM_ENDPOINTS["charge-schedule"],
@@ -130,6 +200,14 @@ _VEHICLE_ENDPOINTS: dict[str, dict[str, Optional[str]]] = {
     "XCB1VE": {  # MEGANE E-TECH
         "lock-status": None,
     },
+    "XHN1SU": {  # AUSTRAL
+        "cockpit": _DEFAULT_ENDPOINTS["cockpit"],  # confirmed
+        "hvac-status": None,
+        "location": _DEFAULT_ENDPOINTS["location"],
+        "lock-status": None,
+        "pressure": None,  # Reason: 404
+        "res-state": None,
+    },
     "XJA1VP": {  # CLIO V
         "hvac-status": None,
     },
@@ -142,7 +220,9 @@ _ALREADY_WARNED_VEHICLE: set[str] = set()
 _ALREADY_WARNED_VEHICLE_ENDPOINT: set[str] = set()
 
 
-def get_model_endpoints(model_code: Optional[str]) -> Mapping[str, Optional[str]]:
+def get_model_endpoints(
+    model_code: Optional[str],
+) -> Mapping[str, Optional[EndpointDefinition]]:
     """Return model endpoints."""
     if not model_code:
         # Model code not available
@@ -153,14 +233,18 @@ def get_model_endpoints(model_code: Optional[str]) -> Mapping[str, Optional[str]
         if model_code not in _ALREADY_WARNED_VEHICLE:
             _ALREADY_WARNED_VEHICLE.add(model_code)
             _LOGGER.warning(
-                "Model %s is not documented, using default endpoints", model_code
+                "Model %s is not documented, using default endpoints."
+                " Please open an issue at https://github.com/hacf-fr/renault-api",
+                model_code,
             )
         return _DEFAULT_ENDPOINTS
 
     return _VEHICLE_ENDPOINTS[model_code]
 
 
-def get_model_endpoint(model_code: Optional[str], endpoint: str) -> Optional[str]:
+def get_model_endpoint(
+    model_code: Optional[str], endpoint: str
+) -> Optional[EndpointDefinition]:
     """Return model endpoint"""
     endpoints = get_model_endpoints(model_code)
 
@@ -170,7 +254,8 @@ def get_model_endpoint(model_code: Optional[str], endpoint: str) -> Optional[str
         if key not in _ALREADY_WARNED_VEHICLE_ENDPOINT:
             _ALREADY_WARNED_VEHICLE_ENDPOINT.add(key)
             _LOGGER.warning(
-                "Endpoint %s for model %s is not documented, using default endpoints",
+                "Endpoint %s for model %s is not documented, using default endpoints."
+                " Please open an issue at https://github.com/hacf-fr/renault-api",
                 endpoint,
                 model_code,
             )
@@ -357,6 +442,11 @@ class KamereonVehicleDetails(BaseModel):
 
     def controls_action_via_kcm(self, action: str) -> bool:
         """Return True if model uses endpoint via kcm."""
+        warn(  # Deprecated in v0.3.2
+            "This method is deprecated, please use get_endpoint.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
         # Default to False for unknown vehicles
         if self.model and self.model.code:
             return VEHICLE_SPECIFICATIONS.get(  # type:ignore[no-any-return]
@@ -364,11 +454,11 @@ class KamereonVehicleDetails(BaseModel):
             ).get(f"control-{action}-via-kcm", False)
         return False
 
-    def get_endpoints(self) -> Mapping[str, Optional[str]]:
+    def get_endpoints(self) -> Mapping[str, Optional[EndpointDefinition]]:
         """Return model endpoints."""
         return get_model_endpoints(self.get_model_code())
 
-    def get_endpoint(self, endpoint: str) -> Optional[str]:
+    def get_endpoint(self, endpoint: str) -> Optional[EndpointDefinition]:
         """Return model endpoint"""
         return get_model_endpoint(self.get_model_code(), endpoint)
 
@@ -488,6 +578,15 @@ class KamereonVehicleBatteryStatusData(KamereonVehicleDataAttributes):
             return None
 
 
+@dataclass
+class KamereonVehicleBatterySocData(KamereonVehicleDataAttributes):
+    """Kamereon vehicle battery state of charge limits data."""
+
+    lastEnergyUpdateTimestamp: Optional[str]
+    socMin: Optional[int]
+    socTarget: Optional[int]
+
+
 @dataclass
 class KamereonVehicleTyrePressureData(KamereonVehicleDataAttributes):
     """Kamereon vehicle tyre-pressure data."""
@@ -617,6 +716,11 @@ class KamereonVehicleCarAdapterData(KamereonVehicleDataAttributes):
 
     def controls_action_via_kcm(self, action: str) -> bool:
         """Return True if model uses endpoint via kcm."""
+        warn(  # Deprecated in v0.3.2
+            "This method is deprecated, please use get_endpoint.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
         # Default to False for unknown vehicles
         if self.modelCodeDetail:
             return VEHICLE_SPECIFICATIONS.get(  # type:ignore[no-any-return]
